
(* :Title: ShowTime *)

(* :Author: Roman E. Maeder *)

(* :Summary:
This package provides a utility to print timing information for each
evaluation.
*)

(*
	Adapted from
	Roman E. Maeder: Programming in Mathematica,
	Second Edition, Addison-Wesley, 1991.
*)

(* :Context: FRB`ShowTime` *)

(* :Copyright: Copyright 1991-1993, Wolfram Research, Inc.*)

(* :Source: Roman E. Maeder: Programming in Mathematica,
		Second Edition, Addison-Wesley, 1991.
*)

(* :Package Version: 1.0 *)

(* :Mathematica Version: 2.0 *)

BeginPackage["FRB`ShowTime`"] (* changed *)

ShowTime::usage = "On[ShowTime] turns timing information on. Off[ShowTime]
turns it off again.  The time taken for each command is printed
before the result (if any)."

ShowTime::twice = "ShowTime is already on."
ShowTime::off = "ShowTime is not in effect."

Begin["`Private`"]

oldPre =.        (* user's value of $Pre *)
ison = False     (* whether ShowTime is currently turned on *)

Attributes[ShowTime] = HoldAll (* changed *)

ShowTime[expr__] := (* changed *)
	Module[{timing},
		Block[{$Pre = oldPre},
			timing = Timing[ oldPre[expr] ];
			Print[ timing[[1]] ];
			oldPre = If[ ValueQ[$Pre], $Pre, ##& ]; (* changed *)
		];
		If[ !ison, $Pre = oldPre ];  (* turn it off again *)
		If[ Length[timing] == 2, timing[[2]],
			Sequence @@ Drop[timing, 1] ] (* changed *)
	]

ShowTime/: On[ShowTime] := (
	If[ ison,
		Message[ShowTime::twice],
	(* else *)
		oldPre = If[ ValueQ[$Pre], $Pre, ##& ]; (* changed *)
		$Pre = ShowTime;
		ison = True
	]; )

ShowTime/: Off[ShowTime] := (
	If[ ison,
		ison = False,
	(* else *)
		Message[ShowTime::off]
	]; )

End[]

EndPackage[]

On[ShowTime]
